@@ -1,13 +1,20 @@
+# pylint: disable=wrong-import-position
+
 import logging
+import warnings
+
+# Grakel internal deprecation
+warnings.filterwarnings("ignore", message="Importing from numpy.matlib is deprecated ")
+
 
 from .api import run
 from .plot.plot import plot
 from .search_spaces import (
+    ArchitectureParameter,
     CategoricalParameter,
     ConstantParameter,
     FloatParameter,
     FunctionParameter,
-    GraphDenseParameter,
     GraphGrammar,
     GraphGrammarCell,
     GraphGrammarRepetitive,
